/* PIKA - Photo and Image Kooker Application
 * a rebranding of The GNU Image Manipulation Program (created with heckimp)
 * A derived work which may be trivial. However, any changes may be (C)2023 by Aldercone Studio
 *
 * Original copyright, applying to most contents (license remains unchanged): 
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef __PIKA_SAMPLE_POINT_H__
#define __PIKA_SAMPLE_POINT_H__


#include "pikaauxitem.h"


#define PIKA_SAMPLE_POINT_POSITION_UNDEFINED G_MININT


#define PIKA_TYPE_SAMPLE_POINT            (pika_sample_point_get_type ())
#define PIKA_SAMPLE_POINT(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), PIKA_TYPE_SAMPLE_POINT, PikaSamplePoint))
#define PIKA_SAMPLE_POINT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), PIKA_TYPE_SAMPLE_POINT, PikaSamplePointClass))
#define PIKA_IS_SAMPLE_POINT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PIKA_TYPE_SAMPLE_POINT))
#define PIKA_IS_SAMPLE_POINT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PIKA_TYPE_SAMPLE_POINT))
#define PIKA_SAMPLE_POINT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), PIKA_TYPE_SAMPLE_POINT, PikaSamplePointClass))


typedef struct _PikaSamplePointPrivate PikaSamplePointPrivate;
typedef struct _PikaSamplePointClass   PikaSamplePointClass;

struct _PikaSamplePoint
{
  PikaAuxItem             parent_instance;

  PikaSamplePointPrivate *priv;
};

struct _PikaSamplePointClass
{
  PikaAuxItemClass  parent_class;
};


GType             pika_sample_point_get_type      (void) G_GNUC_CONST;

PikaSamplePoint * pika_sample_point_new           (guint32            sample_point_ID);

void              pika_sample_point_get_position  (PikaSamplePoint   *sample_point,
                                                   gint              *position_x,
                                                   gint              *position_y);
void              pika_sample_point_set_position  (PikaSamplePoint   *sample_point,
                                                   gint               position_x,
                                                   gint               position_y);

PikaColorPickMode pika_sample_point_get_pick_mode (PikaSamplePoint   *sample_point);
void              pika_sample_point_set_pick_mode (PikaSamplePoint   *sample_point,
                                                   PikaColorPickMode  pick_mode);


#endif /* __PIKA_SAMPLE_POINT_H__ */
