/* PIKA - Photo and Image Kooker Application
 * a rebranding of The GNU Image Manipulation Program (created with heckimp)
 * A derived work which may be trivial. However, any changes may be (C)2023 by Aldercone Studio
 *
 * Original copyright, applying to most contents (license remains unchanged): 
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#include "config.h"

#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gegl.h>

#include "core-types.h"

#include "pikaimage.h"
#include "pikaimage-sample-points.h"
#include "pikasamplepoint.h"
#include "pikasamplepointundo.h"


static void   pika_sample_point_undo_constructed  (GObject             *object);

static void   pika_sample_point_undo_pop          (PikaUndo            *undo,
                                                   PikaUndoMode         undo_mode,
                                                   PikaUndoAccumulator *accum);


G_DEFINE_TYPE (PikaSamplePointUndo, pika_sample_point_undo,
               PIKA_TYPE_AUX_ITEM_UNDO)

#define parent_class pika_sample_point_undo_parent_class


static void
pika_sample_point_undo_class_init (PikaSamplePointUndoClass *klass)
{
  GObjectClass  *object_class = G_OBJECT_CLASS (klass);
  PikaUndoClass *undo_class   = PIKA_UNDO_CLASS (klass);

  object_class->constructed = pika_sample_point_undo_constructed;

  undo_class->pop           = pika_sample_point_undo_pop;
}

static void
pika_sample_point_undo_init (PikaSamplePointUndo *undo)
{
}

static void
pika_sample_point_undo_constructed (GObject *object)
{
  PikaSamplePointUndo *sample_point_undo = PIKA_SAMPLE_POINT_UNDO (object);
  PikaSamplePoint     *sample_point;

  G_OBJECT_CLASS (parent_class)->constructed (object);

  sample_point = PIKA_SAMPLE_POINT (PIKA_AUX_ITEM_UNDO (object)->aux_item);

  pika_assert (PIKA_IS_SAMPLE_POINT (sample_point));

  pika_sample_point_get_position (sample_point,
                                  &sample_point_undo->x,
                                  &sample_point_undo->y);
  sample_point_undo->pick_mode = pika_sample_point_get_pick_mode (sample_point);
}

static void
pika_sample_point_undo_pop (PikaUndo              *undo,
                            PikaUndoMode           undo_mode,
                            PikaUndoAccumulator   *accum)
{
  PikaSamplePointUndo *sample_point_undo = PIKA_SAMPLE_POINT_UNDO (undo);
  PikaSamplePoint     *sample_point;
  gint                 x;
  gint                 y;
  PikaColorPickMode    pick_mode;

  PIKA_UNDO_CLASS (parent_class)->pop (undo, undo_mode, accum);

  sample_point = PIKA_SAMPLE_POINT (PIKA_AUX_ITEM_UNDO (undo)->aux_item);

  pika_sample_point_get_position (sample_point, &x, &y);
  pick_mode = pika_sample_point_get_pick_mode (sample_point);

  if (x == PIKA_SAMPLE_POINT_POSITION_UNDEFINED)
    {
      pika_image_add_sample_point (undo->image,
                                   sample_point,
                                   sample_point_undo->x,
                                   sample_point_undo->y);
    }
  else if (sample_point_undo->x == PIKA_SAMPLE_POINT_POSITION_UNDEFINED)
    {
      pika_image_remove_sample_point (undo->image, sample_point, FALSE);
    }
  else
    {
      pika_sample_point_set_position (sample_point,
                                      sample_point_undo->x,
                                      sample_point_undo->y);
      pika_sample_point_set_pick_mode (sample_point,
                                       sample_point_undo->pick_mode);

      pika_image_sample_point_moved (undo->image, sample_point);
    }

  sample_point_undo->x         = x;
  sample_point_undo->y         = y;
  sample_point_undo->pick_mode = pick_mode;
}
